# 영속성에 관한 대화

> **교수**: 자, 이렇게 해서 운영체제의 네 개의 ... 어 ... 세 개의 기둥 중에 두 번째인 영속성 (persistence)이라는 기둥에 도달했네.

**학생**: 기둥이 세 개라고 하셨나요, 네 개라고 하셨나요? 네 번째는 뭐죠?

> **교수**: 아닐세, 세 개, 어린 학생, 세 기둥일세. 간결하게 만드는 중이야.

**학생**: OK, 좋아요. 그런데 영속성이 뭐죠, 멋지고 고귀하신 교수님?

> **교수**: 사실, 전통적인 의미에서는 어떤 의미를 갖고 있는지는 알고 있을거야, 그렇지? Persistence(영속성)는 사전적으로 "곤경과 반대에도 불구하고 굳게 또는 완고하게 행동 방침을 유지"할 때 쓰는 말이지.

**학생**: 마치 교수님의 수업을 듣는 것과 비슷하네요, 완고함이 필요하거든요.

> **교수**: 하! 그렇구나. 하지만 여기서의 영속성은 다른 의미를 갖고 있단다. 설명해줄게. 밖에 운동장에 서있다고 가정해 보자 그리고 이걸 따려고

**학생**: (끼어들며) 알아요! 복숭아! 복숭아 나무에서요!

> **교수**: 사과나무에서 사과를 따는 것을 말하려고 했다마는. 그래 좋아. 너의 의견을 따르도록 해보자꾸나.

**학생**: (멍하게 바라본다)

> **교수**: 어쨌든, 복숭아를 땄다. 사실 여러 개의 복숭아를 땄어. 그리고 그 복숭아들이 영원히 그대로 있었으면 하는 거야. 위스콘신의 겨울은 알다시피 매섭고 춥잖니? 그러면 어떻게 해야 할까?

**학생**: 그러면, 몇 가지 시도해 볼 수 있을 것 같아요. 절이거나 파이로 굽던가, 아니면 잼같은 것을 만들면 되요. 완전 재미있을 거예요!

> **교수**: 재미있다고? 그래, 그럴수도 있지. 확실한 것은 복숭아를 그대로 유지시키기 위해서는 엄청나게 많은 노력이 필요할거야. 정보도 마찬가지야. 컴퓨터가 멈추거나, 디스크 고장이나 전원이 꺼지는 상황에도 불구하고 정보를 그대로 유지시키는 것은 힘들지만 흥미로운 도전이지.

**학생**: 자연스럽게 흘러가네요. 점점 익숙해지시는 듯해요.

> **교수**: 고맙네! 교수들에게는 그런 친절한 말이 항상 필요하다네.

**학생**: 기억해 둘게요. 이제 복숭아 이야기를 그만하고 컴퓨터 이야기로 넘어가야 할 시간이지요?

> **교수**: 그래 넘어갈 시간이지...
